@@ -244,18 +244,22 @@ class Loaf:
     def select(self, select, fromm="", where="", order="", limit=""):
         # Sanity check.
         if select == "":
-            raise Exception("No SELECT specified.")
+            raise Exception("No FROM specified.")
         # First fabricate the query.
         query = f"SELECT {select}"
-        query += f" FROM {fromm}" if fromm != "" else ""
-        query += f" WHERE {where}" if where != "" else ""
-        query += f" ORDER BY {order}" if order != "" else ""
-        query += f" LIMIT {limit}" if limit != "" else ""
+        query += f" FROM {parse(fromm)}" if fromm != "" else ""
+        query += f" WHERE {parse(where)}" if where != "" else ""
+        query += f" ORDER BY {parse(order)}" if order != "" else ""
+        query += f" LIMIT {parse(limit)}" if limit != "" else ""
         query += ";"
         # Execute the query.
         self.cursor.execute(query)
         return self.cursor.fetchall()
 
+    # A quick SELECT * FROM query.
+    def selectAll(self, fromm="", where="", order="", limit=""):
+        return self.select("*", fromm, where, order, limit)
+
     # A quick INSERT-INTO-VALUES query. The 'into' argument can be a string or a list of strings. The 'values' argument can be a string or a list of strings. If the 'values' argument is a list, it must be the same length as the 'into' argument.
     def insert(self, table, into, values, rollback_on_error=None):
         # Getting the rollback.
